PasswordResetRequest class sealed

Meta-Class for multiple API-Endpoints

Annotations
  • @freezed

Properties

copyWith → $PasswordResetRequestCopyWith<PasswordResetRequest>
Create a copy of PasswordResetRequest with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
oobCode → String
The email action code sent to the user's email for resetting the password.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this PasswordResetRequest to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited